package pps.core.common.utils;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.UUID;
import org.apache.commons.lang3.StringUtils;
import pps.core.common.entity.BaseModel;
import pps.core.common.session.PpsUserSession;

import java.util.Date;

/**
 * 封装工具类
 *
 * @author ZWT
 * @date 2023/08/25 16:08
 */
public class BaseUtils {

    /**
     * 设置实体默认值
     *
     * @param model   实体
     * @param session 会话
     */
    public static void setBaseModelDefault(BaseModel model, PpsUserSession session) {
        String id = model.getId();
        Date now = new Date();
        String userId = session.getId();
        String userName = session.getUserName();
        if (StringUtils.isEmpty(id)) {
            model.setCreateById(userId);
            model.setCreateByName(userName);
            model.setCreateTime(now);
        }
        model.setModifyById(userId);
        model.setModifyByName(userName);
        model.setModifyTime(now);
    }

    /**
     * 设置实体默认值(定时任务)
     *
     * @param model 模型
     */
    public static void setBaseModelDefaultForJob(BaseModel model) {
        Date now = new Date();
        model.setId(BaseUtils.getUUID());
        model.setCreateById("Task");
        model.setCreateByName("Task");
        model.setCreateTime(now);
        model.setModifyById("Task");
        model.setModifyByName("Task");
        model.setModifyTime(now);
    }

    /**
     * 获取uuid
     *
     * @return {@link String}
     */
    public static String getUUID() {
        return StringUtils.replace(UUID.randomUUID().toString(), "-", "");
    }

    /**
     * 获取月份执行周期
     *
     * @param date 日期
     * @return {@link String}
     */
    public static String getExecutionCycleForMonth(Date date) {
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append(DateUtil.format(DateUtil.beginOfMonth(date), "yyyy-MM-dd"))
                .append('-')
                .append(DateUtil.format(DateUtil.endOfMonth(date), "yyyy-MM-dd"));
        return stringBuilder.toString();
    }
}